use std::{fs, path::PathBuf, str::FromStr};

use log::info;
use ropey::Rope;
use tower_lsp::lsp_types::*;

use crate::sources::LSPSupport;

use super::to_escape_path;

pub fn get_range_text(path: &PathBuf, range: &Range) -> Option<String> {
    let path = to_escape_path(path);
    if let Some(rope) = open_doc_as_rope(&path) {
        let start_index = rope.pos_to_byte(&range.start);
        let end_index = rope.pos_to_byte(&range.end);
        info!("start index: {}, end index: {}", start_index, end_index);
        return Some(rope.slice(start_index..end_index).to_string());
    }
    None
}

pub fn open_doc_as_rope(path: &PathBuf) -> Option<Rope> {
    if let std::result::Result::Ok(text) = fs::read_to_string(path) {
        let rope = Rope::from_str(text.as_str());
        Some(rope)
    } else {
        None
    }
}